==> apache-opennlp_1.9.4.orig.tar.gz: apache-opennlp-1.9.4-src/opennlp-tools/src/main/java/opennlp/tools/formats/convert/POSToTokenSampleStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.formats.convert;

import java.io.IOException;
import java.util.Objects;

import opennlp.tools.postag.POSSample;
import opennlp.tools.tokenize.Detokenizer;
import opennlp.tools.tokenize.TokenSample;
import opennlp.tools.util.FilterObjectStream;
import opennlp.tools.util.ObjectStream;

/**
 * <b>Note:</b> Do not use this class, internal use only!
 */
public class POSToTokenSampleStream extends FilterObjectStream<POSSample, TokenSample> {

  private final Detokenizer detokenizer;

  public POSToTokenSampleStream(Detokenizer detokenizer, ObjectStream<POSSample> samples) {
    super(samples);

    this.detokenizer = Objects.requireNonNull(detokenizer, "detokenizer must not be null!");
  }

  public TokenSample read() throws IOException {

    POSSample posSample = samples.read();

    TokenSample tokenSample = null;

    if (posSample != null ) {
      tokenSample = new TokenSample(detokenizer, posSample.getSentence());
    }

    return tokenSample;
  }
}

==> apache-opennlp_2.5.3.orig.tar.gz: apache-opennlp-2.5.3-src/opennlp-tools/src/main/java/opennlp/tools/formats/convert/POSToTokenSampleStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.formats.convert;

import java.io.IOException;
import java.util.Objects;

import opennlp.tools.commons.Internal;
import opennlp.tools.postag.POSSample;
import opennlp.tools.tokenize.Detokenizer;
import opennlp.tools.tokenize.TokenSample;
import opennlp.tools.util.FilterObjectStream;
import opennlp.tools.util.ObjectStream;

/**
 * <b>Note:</b>
 * Do not use this class, internal use only!
 */
@Internal
public class POSToTokenSampleStream extends FilterObjectStream<POSSample, TokenSample> {

  private final Detokenizer detokenizer;

  /**
   * Initializes a {@link POSToTokenSampleStream}.
   *
   * @param detokenizer The {@link Detokenizer} to use. Must not be {@code null}.
   * @param samples The {@link ObjectStream<POSSample> samples} as input. Must not be {@code null}.
   *
   * @throws IllegalArgumentException Thrown if parameters are invalid.
   */
  public POSToTokenSampleStream(Detokenizer detokenizer, ObjectStream<POSSample> samples) {
    super(samples);
    this.detokenizer = Objects.requireNonNull(detokenizer, "detokenizer must not be null!");
  }

  @Override
  public TokenSample read() throws IOException {

    POSSample posSample = samples.read();
    TokenSample tokenSample = null;

    if (posSample != null ) {
      tokenSample = new TokenSample(detokenizer, posSample.getSentence());
    }

    return tokenSample;
  }
}
